// Generated by dts-bundle-generator v9.5.1

import { AxiosPromise } from 'axios';
import { GeoJsonProperties, LineString, Point } from 'geojson';
import maplibregl$1 from 'maplibre-gl';
import { ControlPosition, FilterSpecification, IControl, LngLat, Map as MaplibreMap, MapGeoJSONFeature, MapLayerEventType, PaddingOptions, PointLike, RequireAtLeastOne } from 'maplibre-gl';

export declare enum FloorSwitchMode {
	SWITCHED_BY_BUILDING = 0,
	SWITCHED_BY_VENUE = 1
}
/**
 * @deprecated Use enum `PresetLanguage` instead.
 */
export type TPresetLanguage = "en" | "zh-Hans" | "zh-Hant" | "ja" | "ko";
export declare enum PresetLanguage {
	ENGLISH = "en",
	CHINESE_SIMPLIFIED = "zh-Hans",
	CHINESE_TRADITIONAL = "zh-Hant",
	JAPANESE = "ja",
	KOREAN = "ko"
}
export declare enum ThemeType {
	CHRISTMAS = "christmas",
	HALLOWEEN = "halloween",
	MAPPY_BEE = "mappyBee",
	MAPXUS = "mapxus",
	LANDS_D = "landsD",
	COMMON = "common",
	MAPXUS_V2 = "mapxus_v2"
}
export interface IBbox {
	maxLat: number;
	maxLon: number;
	minLat: number;
	minLon: number;
}
export interface IBuildingChangedOptions {
	buildingId: string | null;
	ordinal: string | null;
}
export interface IMultilingualName extends Partial<Record<PresetLanguage, string>> {
	default: string;
}
export type IMultilingualAddress = Record<keyof IMultilingualName, {
	housenumber: string;
	street: string;
}>;
export interface ILocation {
	lat: number;
	lon: number;
}
export interface IResponse<T> {
	code: number;
	message: string;
	result: T;
}
export interface IBuildingInlineFloor {
	code: string;
	id: string;
	ordinal: number;
	signalMap: boolean;
	visualMap: boolean;
}
export interface IBuilding {
	address: IMultilingualAddress;
	bbox: IBbox;
	buildingId: string;
	buildingOutlineId: number;
	city?: string;
	country: string;
	defaultFloor?: string;
	floors: IBuildingInlineFloor[];
	groundFloor: string;
	isPrivate: "yes" | "no";
	labelCenter: ILocation;
	name: IMultilingualName;
	organization: string;
	region: string;
	signalMap: boolean;
	type: string;
	venueId: string;
	venueName: IMultilingualName;
	visualMap: boolean;
}
export interface IResponseBuildings {
	buildings: IBuilding[];
	total: number;
}
export type TPromiseBuildings = AxiosPromise<IResponse<IResponseBuildings>>;
export type TPointFeature = GeoJSON.Feature<Point, GeoJsonProperties>;
export type TLineStringFeature = GeoJSON.Feature<LineString, GeoJsonProperties>;
export interface IFloor {
	code: string | null;
	id: string | null;
	ordinal: string | null;
}
/**
 * @deprecated Use 'IFloorSelectorStyle' instead.
 */
export interface IFloorsControlStyle {
	fontColor?: string;
	activeFontColor?: string;
	backgroundColor?: string;
	activeBackgroundColor?: string;
	itemSize?: number;
	itemCount?: number;
	defaultFolded?: boolean;
}
export interface IFloorSelectorStyle {
	fontColor?: string;
	activeFontColor?: string;
	backgroundColor?: string;
	activeBackgroundColor?: string;
	itemSize?: number;
	itemCount?: number;
	defaultFolded?: boolean;
}
export interface IMapClickEvent {
	coordinate: LngLat;
	building: MapGeoJSONFeature | null;
	venue: MapGeoJSONFeature | null;
	floor: IFloor;
}
export interface ISelectedBuildingBorderStyle {
	lineWidth?: number;
	lineColor?: string;
	lineOpacity?: number;
}
export interface IMapOption {
	map: maplibregl$1.Map;
	appId: string;
	secret: string;
	/** @deprecated Use 'floorSelectorEnabled' instead */
	enableFloorControl?: boolean;
	floorSelectorEnabled?: boolean;
	/** @deprecated Use 'buildingSelectorEnabled' instead */
	enableBuildingSelector?: boolean;
	buildingSelectorEnabled?: boolean;
	/**
	 * @description 'venueId', 'buildingId', 'floorId', 'poiId' are mutually exclusive,
	 * the priority is: poiId > floorId > buildingId > venueId.
	 */
	venueId?: string;
	/**
	 * @description 'venueId', 'buildingId', 'floorId', 'poiId' are mutually exclusive,
	 * the priority is: poiId > floorId > buildingId > venueId.
	 */
	buildingId?: string;
	/**
	 * @description 'venueId', 'buildingId', 'floorId', 'poiId' are mutually exclusive,
	 * the priority is: poiId > floorId > buildingId > venueId.
	 */
	floorId?: string;
	/**
	 * @description Initialize the map with POI as the center point, use it with maplibregl.Map 'zoom' option.
	 * 'venueId', 'buildingId', 'floorId', 'poiId' are mutually exclusive,
	 * the priority is: poiId > floorId > buildingId > venueId.
	 */
	poiId?: string;
	/**
	 * @deprecated Use 'outdoorMapShown' instead.
	 */
	hiddenOutdoor?: boolean;
	outdoorMapShown?: boolean;
	theme?: ThemeType | string;
	collapseCopyright?: boolean;
	selectedBuildingBorderStyle?: ISelectedBuildingBorderStyle;
	/**
	 * @deprecated Use 'floorSelectorStyle' instead.
	 */
	floorsControlStyle?: IFloorsControlStyle;
	floorSelectorStyle?: IFloorSelectorStyle;
	/**
	 * @description Switch floors by venue/building, default by venue.
	 */
	floorSwitchMode?: FloorSwitchMode;
	/**
	 * @description Whether unselected buildings are masked, default is false.
	 */
	maskNonSelectedAreas?: boolean;
	/**
	 * @description Whether the boundary of the selected building fits the screen, default is false.
	 * Can only be used for 'floorId', 'buildingId' and 'venueId' initialization, not for 'poiId'.
	 * When it is true, the 'boundsPadding' option is valid, and the 'zoom' option of maplibregl.Map is invalid.
	 */
	fitBuildingBounds?: boolean;
	/**
	 * @description The amount of padding in pixels to add to the given bounds, default is 30.
	 * Requires 'fitBuildingBounds' to be 'true'.
	 * Parameter value ref to: https://maplibre.org/maplibre-gl-js/docs/API/types/maplibregl.PaddingOptions/
	 */
	boundsPadding?: number | RequireAtLeastOne<PaddingOptions>;
	language?: PresetLanguage;
}
export type TAnchorPosition = "center" | "left" | "right" | "top" | "bottom" | "top-left" | "top-right" | "bottom-left" | "bottom-right";
export interface IMarkerOptions {
	lngLat: [
		number,
		number
	];
	properties?: {
		[k: string]: string;
	};
}
export interface IMarkerOptionsWithFeatureId extends IMarkerOptions {
	featureId: number;
}
export interface IPoiEvent {
	coordinate: LngLat;
	poi: MapGeoJSONFeature;
	building: MapGeoJSONFeature | null;
	venue: MapGeoJSONFeature | null;
	floor: IFloor;
}
export interface IPointEvent {
	coordinate: LngLat;
	point: PointLike;
}
export interface IPoi {
	accessibilityDetail: IMultilingualName;
	buildingId: string;
	category: string[];
	distance: number;
	floor: string;
	floorId: string;
	id: string;
	location: ILocation;
	name: IMultilingualName;
	osmRefId: number;
	poiId: string;
	venueId: string;
	/** @deprecated 'description' will be removed soon */
	description?: string;
	descriptions?: IMultilingualName;
	email?: string;
	openingHours?: string;
	phone?: string;
	website?: string;
}
export interface IResponsePois {
	pois: IPoi[];
	total: number;
}
export type TPromisePois = AxiosPromise<IResponse<IResponsePois>>;
export type TPromiseCategories = AxiosPromise<IResponse<IPoiCategory[]>>;
export type TPromiseOrientationPois = AxiosPromise<IResponse<IOrientationPoi[]>>;
export declare enum DistanceSearchType {
	POINT = "Point",
	POLYGON = "Polygon",
	GATE = "Gate"
}
export interface IPoiCategory {
	category: string;
	description: string | null;
	id: string;
	title: Partial<Record<keyof IMultilingualName, string>>;
}
export interface IOrientationPoi {
	angle: number;
	buildingId: string;
	category: string[];
	distance: number;
	distanceSource: string;
	floor: string;
	floorId: string;
	id: string;
	location: ILocation;
	name: IMultilingualName;
	osmRefId: number;
	poiId: string;
	description?: string;
	email?: string;
	openingHours?: string;
	phone?: string;
	website?: string;
}
export interface ISearchDistance {
	/**
	 * The center of searching range, [lng, lat].
	 */
	center: [
		number,
		number
	];
	/**
	 * Radius from center, unit is meter, cannot exceed 10,000.
	 */
	distance: number;
	/**
	 * The maximum value is 100, default is 10.
	 */
	offset?: number;
	/**
	 * Results for specified page number. Default is 1.
	 */
	page?: number;
}
export interface IPoiSearchByCategoryOptions extends ISearchDistance {
	category: string;
}
export interface IPoiSearchByExcludedCategoriesOptions extends ISearchDistance {
	excludedCategories: string | string[];
}
export type TPoiSearchByCategoryOptions = IPoiSearchByCategoryOptions | IPoiSearchByExcludedCategoriesOptions;
export interface IPoiSearchByDistanceOptions extends ISearchDistance {
	/**
	 * Keywords of POI name.
	 */
	keywords?: string;
}
export interface ISearchOrientation {
	/**
	 * User's position, [lng, lat].
	 */
	center: [
		number,
		number
	];
	/**
	 * The angle between the user's orientation and true north.
	 */
	angle: number;
	/**
	 * The radius with 'center' as the center of the circle.
	 */
	distance: number;
	/**
	 * The type of POI, default is 'Point'.
	 */
	distanceSearchType?: DistanceSearchType;
}
export interface IPoiSearchByOrientationAndBuildingOptions extends ISearchOrientation {
	buildingId: string;
}
export interface IPoiSearchByOrientationAndFloorOptions extends ISearchOrientation {
	floorId: string;
}
export interface IPoiSearchByOrientationAndOrdinalOptions extends ISearchOrientation {
	ordinal: string;
}
export type TPoiSearchByOrientationOptions = IPoiSearchByOrientationAndBuildingOptions | IPoiSearchByOrientationAndFloorOptions | IPoiSearchByOrientationAndOrdinalOptions;
export interface IPoiSearchOrientationOptions {
	/**
	 * User's current position, [lng, lat].
	 */
	center: [
		number,
		number
	];
	/**
	 * The angle between cellphone's orientation and the north.
	 */
	angle: number;
	/**
	 * Radius.
	 */
	distance: number;
	buildingId?: string;
	floorId?: string;
	/**
	 * Floor order in physical space, e.g. '-1', '0'(ground floor), '1'...
	 */
	ordinal?: string;
	/**
	 * Search type.
	 */
	distanceSearchType?: DistanceSearchType;
}
export declare enum PoisOrderBy {
	DEFAULT_NAME = "DefaultName"
}
export interface ISearchKeywords {
	keywords?: string;
	/**
	 * Quantity per page, the maximum is 100, default is 10.
	 */
	offset?: number;
	/**
	 * Results for specified page number. Default is 1.
	 */
	page?: number;
}
export interface IPoiSearchByBuildingOptions extends ISearchKeywords {
	buildingId: string;
	orderBy?: PoisOrderBy;
}
export interface IPoiSearchByVenueOptions extends ISearchKeywords {
	venueId: string;
	orderBy?: PoisOrderBy;
}
export interface IPoiSearchByFloorOptions extends ISearchKeywords {
	floorId: string;
	orderBy?: PoisOrderBy;
}
export interface IPoiSearchByBoundsOptions extends ISearchKeywords {
	/**
	 * An array of LngLat coordinates in [sw, ne] order
	 */
	bounds: [
		[
			number,
			number
		],
		[
			number,
			number
		]
	];
	orderBy?: PoisOrderBy;
}
export interface ITokenInfo {
	"app:name": string;
	auth_time: number;
	"cognito:username": string;
	"custom:organization": string;
	exp: number;
	iat: number;
	organization: string;
	"organization:name": string;
	privatization_type: string;
	username: string;
}
export declare enum VehicleType {
	FOOT = "foot",
	WHEELCHAIR = "wheelchair",
	ESCALATOR = "escalator",
	EMERGENCY = "emergency"
}
export interface IRouteInfo {
	copyrights: string[];
	took: number;
}
export interface IInstruction {
	building_id: string;
	distance: number;
	floor_id: string;
	heading: number;
	interval: [
		number,
		number
	];
	ordinal: number;
	sign: number;
	street_name: string;
	text: string;
	time: number;
	type: string | null;
	venue_id: string;
}
export interface IRoutePath {
	bbox: [
		number,
		number,
		number,
		number
	];
	distance: number;
	instructions: IInstruction[];
	points: {
		coordinates: Array<[
			number,
			number
		]>;
		type: string;
	};
	snapped_waypoints: {
		coordinates: Array<[
			number,
			number
		]>;
		type: string;
	};
	time: number;
}
export interface IResponseRoute {
	infos: IRouteInfo | null;
	paths: IRoutePath[];
}
export type TPromiseRoute = AxiosPromise<IResponse<IResponseRoute>>;
export interface IRouteSearchOptions {
	/**
	 * @description Points are in order, from -> stops -> to.
	 * The length of points must be: 1 < {points.length} < 6.
	 */
	points: Array<{
		lat: number;
		lon: number;
		buildingId?: string;
		floorId?: string;
	}>;
	/**
	 * @description Default is "foot".
	 */
	vehicle?: VehicleType;
	/**
	 * @description Language-specific response. Default is "en".
	 */
	locale?: PresetLanguage;
	/**
	 * @description Whether the end point of the route is at the door(otherwise in the room), default is "true".
	 * @deprecated
	 */
	toDoor?: boolean;
}
export interface IVenueInlineBuilding {
	buildingOutlineId: number;
	defaultFloor?: string;
	floors: IBuildingInlineFloor[];
	id: string;
	labelCenter: ILocation;
	name: IMultilingualName;
	point: {
		type: string;
		coordinates: [
			number,
			number
		];
	};
	signalMap: boolean;
	visualMap: boolean;
}
export interface IVenue {
	address: IMultilingualAddress;
	bbox: IBbox;
	buildings: IVenueInlineBuilding[];
	businessStatus?: {
		status: string;
	};
	country: string;
	defaultBuilding?: string;
	id: string;
	labelCenter: ILocation;
	name: IMultilingualName;
	organization: string[];
	owner: string;
	publicData?: string[];
	photos?: object[];
	region: string;
	restricted: boolean;
	signalMap: boolean;
	totalPhotoCount?: number;
	type: string;
	venueOutlineId: number;
	visualMap: boolean;
}
export interface IResponseVenues {
	venues: IVenue[];
	total: number;
}
export type TPromiseVenues = AxiosPromise<IResponse<IResponseVenues>>;
export type Listener = (param: any) => any;
declare class Event$1 {
	private _type;
	private _target;
	constructor(type: string, data?: Object);
	get type(): string;
	set type(type: string);
	get target(): Evented;
	set target(target: Evented);
}
/** MixedEvent class */
export declare class Evented {
	private _listeners;
	private _oneTimeListeners;
	private _eventedParent;
	private _eventedParentData;
	/**
	 * @description Register a new event listener
	 * @param type name of the event(a unique string)
	 * @param listener event handler, it will be called when the event is fired
	 */
	on(type: string, listener: Listener): this;
	/**
	 * @description Remove a registered event listener
	 * @param type name of the event
	 * @param listener event handler
	 */
	off(type: string, listener: Listener): this;
	/**
	 * Adds a listener that will be called only once to a specified event type.
	 *
	 * The listener will be called first time the event fires after the listener is registered.
	 *
	 * @param {string} type The event type to listen for.
	 * @param {Function} listener The function to be called when the event is fired the first time.
	 * @returns {Object} `this`
	 */
	once(type: string, listener: Listener): this;
	fire(event: Event$1): this;
	/**
	 * Returns a true if this instance of Evented or any forwardeed instances of Evented have a listener for the specified type.
	 *
	 * @param {string} type The event type
	 * @returns {boolean} `true` if there is at least one registered listener for specified event type, `false` otherwise
	 * @private
	 */
	listens(type: string): boolean;
	/**
	 * Bubble all events fired by this instance of Evented to this parent instance of Evented.
	 *
	 * @returns {Object} `this`
	 * @private
	 */
	setEventedParent(parent: Evented, data?: Object | (() => Object)): this;
}
export declare class Indoor extends Evented {
	private _map;
	private _features;
	private _allBuildings;
	private _curBuildingId;
	private _curBuildingFeature;
	private _ordinal;
	private _floorId;
	private _floorName;
	private _allowOutdoorSwitch;
	private _allowBuildingSwitch;
	private _outdoorMapShown;
	private _originIndoorLayers;
	private _curVenueId;
	private _curVenueFeature;
	private _buildingHighlightStyle;
	private _lowerLayers;
	private _upperLayers;
	private _commonLayers;
	private _dispatch;
	private readonly _fitBuildingBounds;
	private readonly _boundsPadding;
	private readonly _startWithIndoorView;
	private _maplibreMapLoaded;
	private _indoorMapLoaded;
	private readonly _isVenueMode;
	private _isMaskMode;
	private _upperBuildings;
	private _lowerBuildings;
	private readonly _hiddenBuildings;
	private _upperLevels;
	private _lowerLevels;
	private _history;
	private _featureIncomplete;
	private _isSwitchBuildingByClickMap;
	constructor(props: {
		map: MaplibreMap;
		floorSwitchMode?: FloorSwitchMode;
		fitBuildingBounds?: boolean;
		boundsPadding?: number | RequireAtLeastOne<PaddingOptions>;
		maskNonSelectedAreas?: boolean;
		/**
		 * @deprecated Use 'startWithIndoorView' instead.
		 */
		isInitialIndoor?: boolean;
		startWithIndoorView?: boolean;
		/**
		 * @deprecated Use 'outdoorMapShown' instead.
		 */
		isHiddenOutdoor?: boolean;
		outdoorMapShown?: boolean;
		selectedBuildingBorderStyle?: ISelectedBuildingBorderStyle;
	});
	/**
	 * @description Turn on indoor-outdoor switching.
	 * @deprecated Use 'setAllowOutdoorSwitch(true)' instead.
	 */
	enableSwitch(): this;
	/**
	 * @description Turn off indoor-outdoor switching.
	 * @deprecated Use 'setAllowOutdoorSwitch(false)' instead.
	 */
	disableSwitch(): this;
	/**
	 * @description Set whether to allow exiting building.
	 * @param allow
	 */
	setAllowOutdoorSwitch(allow: boolean): this;
	/**
	 * @description Turn on building-building switching.
	 * @deprecated Use 'setAllowBuildingSwitch(true)' instead.
	 */
	enableSwitchBuilding(): this;
	/**
	 * @description Turn off building-building switching.
	 * @deprecated Use 'setAllowBuildingSwitch(false)' instead.
	 */
	disableSwitchBuilding(): this;
	/**
	 * @description Set whether to allow switching building.
	 * @param allow
	 */
	setAllowBuildingSwitch(allow: boolean): this;
	/**
	 * @description Get the current floor's information.
	 */
	get floor(): IFloor;
	/**
	 * @description Get the current building's information.
	 * @returns {MapGeoJSONFeature | null}
	 */
	get building(): MapGeoJSONFeature | null;
	/**
	 * @description Get the current venue's information.
	 * @returns {MapGeoJSONFeature | null}
	 */
	get venue(): MapGeoJSONFeature | null;
	/**
	 * @description Get the geo features of bbox.
	 */
	get features(): MapGeoJSONFeature[];
	/**
	 * @description Get specified feature of bbox by id.
	 * @deprecated Use 'getFeaturesById' instead.
	 * @param id
	 * @return {MapGeoJSONFeature | undefined}
	 */
	getFeature(id: string): MapGeoJSONFeature | undefined;
	/**
	 * @description Get features from bbox by id.
	 * @param id
	 * @param options
	 */
	getFeaturesById(id: string, options?: {
		layerIds?: string[];
		filter?: (feature: MapGeoJSONFeature) => boolean;
	}): MapGeoJSONFeature[];
	/**
	 * @description Get level feature at the point
	 * @param point
	 * @return {MapGeoJSONFeature | null}
	 */
	getLevelByPoint(point: PointLike): MapGeoJSONFeature | null;
	/**
	 * @description Map pan to the building center and select the building.
	 * @param buildingId
	 * @param floorId
	 * @param callback - **@deprecated** The optional parameter **'callback' will be removed soon**, you
	 * should use this method as `await panToBuilding(buildingId)` or `panToBuilding(buildingId).then()`
	 */
	panToBuilding(buildingId: string, floorId?: string, callback?: (feature: MapGeoJSONFeature) => void): Promise<void>;
	/**
	 * @description Switch floor by ordinal.
	 * @param ordinal
	 * @param dragPan
	 */
	switchFloorByOrdinal(ordinal: string | null, dragPan?: boolean): void;
	/**
	 * @description Hide the outdoor layer.
	 * @deprecated Use 'setOutdoorMapShown' instead.
	 * @param isHiddenOutdoor
	 */
	hiddenOutdoorLayer(isHiddenOutdoor: boolean): void;
	setOutdoorMapShown(shown: boolean): void;
	/**
	 * @description Update map layout.
	 */
	updateCustomLayers(): void;
	/**
	 * @description Set the style of SelectedBuildingBorder. If set to null, the border will be invisible.
	 * @param style {ISelectedBuildingBorderStyle | null}
	 */
	setSelectedBuildingBorderStyle(style: ISelectedBuildingBorderStyle | null): void;
	/**
	 * @description Set whether to cover the unselected venues/buildings.
	 * @deprecated
	 * @param mask Default is false.
	 */
	setMaskNonSelectedAreas(mask: boolean): void;
	/**
	 * @description Listen for the indoor map state, including the changes of venue, building and floor.
	 * @param listener
	 */
	onMapChange(listener: (params: {
		venue: MapGeoJSONFeature | null;
		building: MapGeoJSONFeature | null;
		floor: IFloor;
	}) => void): {
		unsubscribe: VoidFunction;
	};
	/**
	 * @description Select a building feature
	 * @param feature {MapGeoJSONFeature | null}
	 * @param options {floorId?: string, dragPan?: boolean}
	 */
	selectBuilding(feature: MapGeoJSONFeature | null, options?: {
		floorId?: string;
		featureIncomplete?: boolean;
	}): Promise<void>;
	updateRendering(): void;
	private _getBuildingByPoint;
	private _loadData;
	private _init;
	private _clear;
	private _getIndoorFeatures;
	private _getBuildingFloorByOrdinal;
	private _isNotCurrentFeature;
	private _setOutdoorVisibility;
	private _addCustomLevelFillLayer;
	private _setBuildingLineOpacity;
	private _addBuildingHighlightLayer;
	private _filterBuildingHighlight;
	private _handleBuildings;
	private _getVenueDefaultOrdinal;
	private _getBuildingDefaultOrdinal;
	private _getBuildingsOfBbox;
	private _copyOverlapLayers;
	private _layerDisplayedBuildings;
	private _setDisplayedLevels;
	private _filterTiles;
	private _filterIndoorLayers;
	private _updateIndoorState;
	private _updateFloorState;
	private _resetSelectedBuildingLevel;
	private _checkAndPanToBuilding;
	private _invisibleSelectedBuilding;
}
export declare class BuildingFilterControl implements IControl {
	private _map;
	private _maplibre;
	private _indoor;
	private _buildingId;
	private _features;
	private _container;
	private _buildingNameLayout;
	private _buildingNameList;
	private _listHeight;
	private _visible;
	private _position;
	/**
	 * @param map
	 * @param position - **@deprecated** The optional parameter **'position' will be removed soon**.
	 * @param buildingSelectorEnabled
	 */
	constructor(map: Map$1, position?: ControlPosition, buildingSelectorEnabled?: boolean);
	onAdd(map: MaplibreMap): HTMLElement;
	onRemove(): void;
	get position(): ControlPosition;
	get enabled(): boolean;
	getDefaultPosition(): ControlPosition;
	/**
	 * @deprecated Use 'setVisibility' instead.
	 * @param isHidden
	 */
	setLayoutHidden(isHidden: boolean): void;
	setVisibility(isVisible: boolean): void;
	/**
	 * @deprecated Use 'changePosition' instead.
	 * @param from
	 * @param to
	 */
	moveBuildingFilter(from: ControlPosition, to: ControlPosition): void;
	changePosition(from: ControlPosition, to: ControlPosition, index?: number): void;
	private _loadData;
	private _init;
	private _refresh;
	private _select;
	private _load;
	private _buildingFilterIconCreate;
	private _buildingNameListCreate;
	private _buildingNameListUpdate;
	private _buildingNameListClean;
	private _setBuildingListHeight;
	private _buildingNameCreate;
	private _toggleList;
	private _buildingNameClickEvent;
	private _buildingToggleListEvent;
	private _$showLayout;
	private _$hideLayout;
	private _updateBuildingListLayout;
}
export interface IFloorSelectorOptions {
	style?: IFloorSelectorStyle;
	enabled?: boolean;
}
export declare class FloorsControl implements IControl {
	private _container;
	private _indoor;
	private _maplibre;
	private _position;
	private _buildingId;
	private _floorNames;
	private _ordinals;
	private _ordinal;
	private _style;
	private _$innerFloors;
	private _$activeFloor;
	private _centerSelectorIdx;
	private _lastNormalScrollableIdx;
	private _$arrowBtnUp;
	private _$arrowBtnDown;
	private _maxScrollTop;
	private _$selectorExpanded;
	private _$selectorFolded;
	private _componentDidMount;
	private _isEnabled;
	private _visible;
	private _dragPan;
	/**
	 * @param indoor
	 * @param options
	 */
	constructor(indoor: Indoor, options: IFloorSelectorOptions);
	onAdd(map: MaplibreMap): HTMLElement;
	onRemove(): void;
	get position(): ControlPosition;
	get enabled(): boolean;
	setEnabled(enabled: boolean): void;
	getDefaultPosition(): ControlPosition;
	/**
	 * @description Switch floor by ordinal
	 * @param ordinal
	 */
	switchByOrdinal(ordinal: string): void;
	/**
	 * @deprecated
	 * @param visible
	 */
	setVisibility(visible: boolean): void;
	/**
	 * @deprecated Use 'changePosition' instead.
	 * @param position
	 */
	setPosition(position: ControlPosition): void;
	changePosition(from: ControlPosition, to: ControlPosition, index?: number): void;
	setStyle(style: Partial<IFloorSelectorStyle>): void;
	setDragPan(dragPan: boolean | undefined): void;
	private _setVisibility;
	private _bindEvents;
	private _addMapMoveEventListener;
	private _mountFloors;
	private _updateFloorSelector;
	private _clearState;
	private _render;
	private _hide;
	private _show;
	private _createFloors;
	private _$expandedSelector;
	private _$foldedSelector;
	private _clearFloors;
	private _$createScrollButton;
	private _$createFloors;
	private _updateSelectorStatus;
	private _resetArrowBtnStatus;
	private _resetActiveFloor;
	private _scrollCenterActiveFloor;
	private _getScrollTop;
	private _handleScroll;
	private _expandSelector;
}
export declare class BuildingSelectorHandler {
	private _buildingSelector;
	private _isEnabled;
	private _position;
	constructor(buildingSelector: BuildingFilterControl);
	enable(): void;
	disable(): void;
	/**
	 * Set the position of the building selector control
	 * @param position
	 * @param index - The index of the control in the controls-container. Default at the last.
	 */
	setPosition(position: ControlPosition, index?: number): void;
	get isEnabled(): boolean;
	get position(): ControlPosition;
}
export declare class FloorSelectorHandler {
	private _floorSelector;
	private _isEnabled;
	private _position;
	constructor(floorSelector: FloorsControl);
	enable(): void;
	disable(): void;
	/**
	 * Set the position of the floor selector control
	 * @param position
	 * @param index - The index of the control in the controls-container. Default at the last.
	 */
	setPosition(position: ControlPosition, index?: number): void;
	setStyle(style: IFloorSelectorStyle): void;
	get isEnabled(): boolean;
	get position(): ControlPosition;
}
export declare class SwitchBuildingHandler {
	private _indoor;
	private _isEnabled;
	constructor(indoor: Indoor);
	enable(): void;
	disable(): void;
	get isEnabled(): boolean;
}
export declare class SwitchOutdoorHandler {
	private _indoor;
	private _isEnabled;
	constructor(indoor: Indoor);
	enable(): void;
	disable(): void;
	get isEnabled(): boolean;
}
declare class Map$1 extends Evented {
	private _map;
	private _indoor;
	private _poi;
	private _floorsControl;
	private _buildingFilterControl;
	private _attributionControl;
	private _initialHiddenLayers;
	private _language;
	private _dispatch;
	private _fitBuildingBounds;
	private _boundsPadding;
	private _buildingService;
	private _venueService;
	switchOutdoor: SwitchOutdoorHandler;
	switchBuilding: SwitchBuildingHandler;
	buildingSelector: BuildingSelectorHandler;
	floorSelector: FloorSelectorHandler;
	constructor(options: IMapOption);
	/**
	 * @description This function will be called once the indoor source loaded.
	 * @param callback
	 */
	renderComplete(callback: VoidFunction): void;
	/**
	 * @description Get map indoor instance.
	 */
	getIndoor(): Indoor;
	/**
	 * @description Get maplibre map instance.
	 */
	getMaplibre(): maplibregl$1.Map;
	/**
	 * @description Get maplibre map instance.
	 * @deprecated Use 'getMaplibre' instead.
	 */
	getMap(): maplibregl$1.Map;
	/**
	 * @description Get current selected floor info.
	 * @return {IFloor | null}
	 */
	get floor(): IFloor | null;
	/**
	 * @description Get current selected building info.
	 * @return {MapGeoJSONFeature | null}
	 */
	get building(): MapGeoJSONFeature | null;
	/**
	 * @description Get current selected venue info.
	 * @return {MapGeoJSONFeature | null}
	 */
	get venue(): MapGeoJSONFeature | null;
	/**
	 * @description Translate POI name to the specified language.
	 * @deprecated Use 'setLanguage' instead.
	 * @param language Window.navigator.language.
	 */
	transformPoiTextFieldLanguage(language: string): void;
	/**
	 * @description Set map language.
	 * @param language {PresetLanguage} convertBrowserLangToPresetLang(Window.navigator.language).
	 */
	setLanguage(language: PresetLanguage): void;
	/**
	 * @description Turn on indoor-outdoor switching.
	 * @deprecated Use 'switchOutdoor.enable()' instead.
	 */
	enableSwitch(): this;
	/**
	 * @description Turn off indoor-outdoor switching.
	 * @deprecated Use 'switchOutdoor.disable()' instead.
	 */
	disableSwitch(): this;
	/**
	 * @description Turn on building-building switching.
	 * @deprecated Use 'switchBuilding.enable()' instead.
	 */
	enableSwitchBuilding(): this;
	/**
	 * @description Turn off building-building switching.
	 * @deprecated Use 'switchBuilding.disable()' instead.
	 */
	disableSwitchBuilding(): this;
	/**
	 * @description Set outdoor layer to be shown or hidden.
	 * @deprecated Use 'setOutdoorMapShown' instead.
	 * @param isHidden True is hidden, false is shown.
	 */
	setOutdoorLayerHidden(isHidden: boolean): void;
	/**
	 * @description Set outdoor map to be shown or hidden.
	 * @param shown
	 */
	setOutdoorMapShown(shown: boolean): void;
	/**
	 * @description Get feature in bbox by id.
	 * @deprecated Use 'getFeaturesById' instead.
	 * @param id
	 * @return {MapGeoJSONFeature | undefined}
	 */
	getFeature(id: string): MapGeoJSONFeature | undefined;
	/**
	 * @description Get features from bbox by coordinates [and ordinal].
	 * @param coordinates
	 * @param ordinal
	 */
	getIndoorFeaturesByCoordinates(coordinates: {
		lng: number;
		lat: number;
	}, ordinal?: number): {
		venue: MapGeoJSONFeature;
		building: MapGeoJSONFeature;
		level: MapGeoJSONFeature;
	};
	/**
	 * @description Query rendered features from bbox by id. One id may correspond to multiple features,
	 * coz of a feature may be multi-polygon(feature collection).
	 * @param id
	 * @param options {layerIds: string[], filter: (feature: MapGeoJSONFeature) => boolean}
	 */
	getFeaturesById(id: string, options?: {
		layerIds?: string[];
		filter?: (feature: MapGeoJSONFeature) => boolean;
	}): MapGeoJSONFeature[];
	/**
	 * @description Select floor by id.
	 * @param floorId
	 * @param options {dragPan: boolean} Set dragPan to be false, the map will not pan to the building center.
	 * Default is true.
	 */
	selectFloorById(floorId: string, options?: {
		dragPan?: boolean;
	}): Promise<void>;
	/**
	 * @description Select building by id.
	 * @param buildingId
	 * @param options {dragPan: boolean} Set dragPan to be false, the map will not pan to the building center.
	 * Default is true.
	 */
	selectBuildingById(buildingId: string, options?: {
		dragPan?: boolean;
	}): Promise<void>;
	/**
	 * @description Select or exit venue by id.
	 * @param venueId 'venueId' can be string or null. Exit indoors if venueId is null.
	 * @param options {dragPan: boolean} Set dragPan to be false, the map will not pan to the building center.
	 * Default is true.
	 */
	selectVenueById(venueId: string | null, options?: {
		dragPan?: boolean;
	}): Promise<void>;
	/**
	 * @description Listen for mouse click events on the map.
	 * @param listener
	 */
	onMapClickListener(listener: (event: IMapClickEvent) => void): {
		unsubscribe: VoidFunction;
	};
	/**
	 * @description Listen for mouse click events on indoor POI
	 * @param listener
	 */
	onPoiClickListener(listener: (param: IPoiEvent) => void): {
		unsubscribe: VoidFunction;
	};
	/**
	 * @description Listen for mouse click events at a point.
	 * @param listener
	 */
	onPointClickListener(listener: (result: IPointEvent) => void): {
		unsubscribe: VoidFunction;
	};
	/**
	 * @description Listen for the indoor map status, including the changes of venue, building and floor.
	 * @param listener
	 */
	onMapChangeListener(listener: (params: {
		venue: MapGeoJSONFeature | null;
		building: MapGeoJSONFeature | null;
		floor: IFloor;
	}) => void): {
		unsubscribe: VoidFunction;
	};
	/**
	 * @description Hide the BuildingSelector.
	 * @deprecated Use 'buildingSelector.disable()' instead.
	 */
	disableBuildingSelector(): this;
	/**
	 * @description Show the BuildingSelector.
	 * @deprecated Use 'buildingSelector.enable()' instead.
	 * @param position
	 */
	enableBuildingSelector(position?: ControlPosition): this;
	/**
	 * @description Switch the map style
	 * @param theme ThemeType | string(customized map style file name)
	 */
	switchTheme(theme: string): void;
	/**
	 * @description Set the floorsControl's style.
	 * @deprecated Use 'setFloorSelectorStyle' instead.
	 * @param style
	 */
	setFloorsControlStyle(style: IFloorsControlStyle): this;
	/**
	 * @description Set the FloorSelector's style.
	 * @deprecated Use 'map.floorSelector.setStyle()' instead.
	 * @param style
	 */
	setFloorSelectorStyle(style: IFloorSelectorStyle): this;
	/**
	 * @description Set the SelectedBuildingBorder's style. If set to null, the border will be invisible.
	 * @param style {ISelectedBuildingBorderStyle | null}
	 */
	setSelectedBuildingBorderStyle(style: ISelectedBuildingBorderStyle | null): this;
	private _getStyleUrl;
	private _setIndoorFilter;
	private _setStyle;
	private _addControl;
	private _selectPoiById;
	private _resourceRequestTransform;
	private _checkMapZoom;
	private _clickEventsDispatcher;
	private _hideIndoorLayers;
	private _showIndoorLayers;
	private _updatePermission;
	private _panToBuilding;
}
export declare class Marker {
	private readonly _maplibreMap;
	private readonly _layerId;
	private readonly _sourceId;
	private _imageName;
	private _imageSize;
	private _iconAnchor;
	constructor(maplibreMap: MaplibreMap);
	/**
	 * @description Set custom marker image.
	 * @param icon Sprite name in map style or the URL of the image file.
	 * Image file must be in png, webp, or jpg format.
	 */
	setIcon(icon: string): Promise<void>;
	/**
	 * @description Set marker image size.
	 * @param imageScale Default is 1.
	 */
	setIconSize(imageScale: number): void;
	/**
	 * @description Set marker image anchor. Part of the icon placed closest to the anchor.
	 * @param anchor
	 */
	setIconAnchor(anchor: TAnchorPosition): void;
	/**
	 * @description Marker layer id getter.
	 */
	get layerId(): string;
	/**
	 * @description Marker source id getter.
	 */
	get sourceId(): string;
	/**
	 * @description Draw marker[s] on map.
	 * @param array {IMarkerOptions | IMarkerOptionsWithFeatureId[]} Coordinate and properties arrays of marker[s].
	 * If you need to use updateData(), the parameter must be IMarkerOptionsWithFeatureId[].
	 */
	create(array: Array<IMarkerOptions | IMarkerOptionsWithFeatureId>): void;
	/**
	 * @description Add, delete or update features of this marker layer.
	 * This approach requires unique IDs for every feature in the source!!! Including create() parameters.
	 * @param diff {remove: number[], add: IMarkerOptionsWithFeatureId[], update: IMarkerOptionsWithFeatureId[]}
	 * remove: Array of feature IDs to remove.
	 * add: Array of new features to add.
	 * update: Array of features to update, the new properties will replace the old ones.
	 */
	updateData(diff: {
		remove?: number[];
		add?: IMarkerOptionsWithFeatureId[];
		update?: IMarkerOptionsWithFeatureId[];
	}): void;
	/**
	 * @description Remove marker[s] layer and source.
	 */
	remove(): void;
	/**
	 * @description Add marker event listener.
	 * @deprecated Use 'on' method instead.
	 * @param eventKey
	 * @param callback
	 */
	onEventListener(eventKey: keyof MapLayerEventType, callback: (marker: MapGeoJSONFeature) => void): {
		offEventListener: VoidFunction;
	};
	/**
	 * @description Add marker event listener.
	 * @param eventKey
	 * @param callback
	 */
	on(eventKey: keyof MapLayerEventType, callback: (marker: MapGeoJSONFeature) => void): {
		off: () => MaplibreMap;
	};
	/**
	 * @description Filter marker by custom properties.
	 * @param filterExpression A expression specifying conditions on source features.
	 * Only features that match the filter are displayed. Refer:
	 * https://maplibre.org/maplibre-style-spec/expressions/
	 */
	setFilter(filterExpression: FilterSpecification): void;
	/**
	 * @description Filter marker by venueId and ordinal.
	 * Required 'venueId' and 'ordinal' in properties.
	 * Markers not matched 'venueId' and 'ordinal' would be hidden;
	 * Outdoor markers always are shown.
	 * @param venueId {string | null | undefined} null | undefined will be treated as ''.
	 * @param ordinal {string | null | undefined} null | undefined will be treated as ''.
	 */
	setFilterByVenue(venueId: string | null | undefined, ordinal: string | null | undefined): void;
	/**
	 * @description Filter marker by buildingId and ordinal.
	 * Required 'buildingId' and 'ordinal' in properties.
	 * Markers not matched 'buildingId' and 'ordinal' would be hidden;
	 * Outdoor markers always are shown.
	 * @param buildingId {string | null | undefined} null | undefined will be treated as ''.
	 * @param ordinal {string | null | undefined} null | undefined will be treated as ''.
	 */
	setFilterByBuilding(buildingId: string | null | undefined, ordinal: string | null | undefined): void;
	/**
	 * @description Set marker's icon-opacity by custom properties.
	 * @param filterExpression A expression specifying conditions on source features.
	 * Only features that match the filter are displayed. Refer:
	 * https://maplibre.org/maplibre-style-spec/expressions/
	 */
	setOpacity(filterExpression: FilterSpecification): void;
	/**
	 * @description Set marker's icon-opacity by venueId and ordinal.
	 * Required 'venueId' and 'ordinal' in properties.
	 * Opacities of markers matched 'venueId' and 'ordinal' are 1, others are 0.5.
	 * Outdoor markers' opacity always are 1.
	 * @param venueId {string | null | undefined} null | undefined will be treated as ''.
	 * @param ordinal {string | null | undefined} null | undefined will be treated as ''.
	 */
	setOpacityByVenue(venueId: string | null | undefined, ordinal: string | null | undefined): void;
	/**
	 * @description Set marker's icon-opacity by buildingId and ordinal.
	 * Required 'buildingId' and 'ordinal' in properties.
	 * Opacities of markers matched 'buildingId' and 'ordinal' are 1, others are 0.5.
	 * Outdoor markers' opacity always are 1.
	 * @param buildingId {string | null | undefined} null | undefined will be treated as ''.
	 * @param ordinal {string | null | undefined} null | undefined will be treated as ''.
	 */
	setOpacityByBuilding(buildingId: string | null | undefined, ordinal: string | null | undefined): void;
	private _createIconFeature;
	private _addIconSource;
	private _addIconLayer;
	private _handleEventListener;
}
export declare class Poi {
	private _map;
	private _layerIds;
	private _dispatch;
	constructor(map: MaplibreMap);
	/**
	 * @description Listen for POI click events.
	 * @param listener
	 */
	onPoiClick(listener: (param: IPoiEvent) => void): {
		unsubscribe: VoidFunction;
	};
	private _bindEvents;
	private _init;
	private _initPoiClick;
	private _getFloorDataByFloorId;
}
export declare class RoutePainter {
	private readonly _maplibreMap;
	private _fromMarkerIcon;
	private _toMarkerIcon;
	private _stopMarkerIcons;
	private _markerIconSize;
	private _paintProperties;
	constructor(maplibreMap: MaplibreMap);
	/**
	 * @description Set image[s] of the stop marker[s].
	 * @param icons {**Array<string | null> | {from?: string | null; to?: string | null; stops?: Array<string | null> | null;}**}
	 * Array of sprite names or URLs, or the object with specifying icon.
	 * Markers use images in order of icons array.
	 * First is as from-marker, last is as to-marker, the middles are as stop-markers.
	 * If icons array has only one element, all stop markers use this image.
	 * Image file must be in png, webp, or jpg format.
	 * Null means none image.
	 */
	setMarkerIcons(icons: Array<string | null> | {
		from?: string | null;
		to?: string | null;
		stops?: Array<string | null> | null;
	}): Promise<void>;
	/**
	 * @description Set image icon scale.
	 * @param size Default is 1.
	 */
	setMarkerIconSize(size: number): this;
	/**
	 * @description Set the route color of the indoor part.
	 * @param color The color type is a color in the sRGB color space.
	 * Formats: HTML-style hex values, RGB, RGBA, HSL, and HSLA.
	 * Predefined HTML colors names, like yellow and blue, are also permitted.
	 */
	setIndoorLineColor(color: string): this;
	/**
	 * @description Set the route color of the outdoor part.
	 * @param color The color type is a color in the sRGB color space.
	 * Formats: HTML-style hex values, RGB, RGBA, HSL, and HSLA.
	 * Predefined HTML colors names, like yellow and blue, are also permitted.
	 */
	setOutdoorLineColor(color: string): this;
	/**
	 * @description Set color of dashed lines which connected the start and end markers.
	 * @param color The color type is a color in the sRGB color space.
	 * Formats: HTML-style hex values, RGB, RGBA, HSL, and HSLA.
	 * Predefined HTML colors names, like yellow and blue, are also permitted.
	 */
	setDashedLineColor(color: string): this;
	/**
	 * @description Set color of shuttle bus line.
	 * @param color The color type is a color in the sRGB color space.
	 * Formats: HTML-style hex values, RGB, RGBA, HSL, and HSLA.
	 * Predefined HTML colors names, like yellow and blue, are also permitted.
	 */
	setBusLineColor(color: string): this;
	/**
	 * @description Render route on the map.
	 * @param path Route path from RouteService.search response.
	 * @param markerLocations Coordinate([lng, lat]) array of markers, order from beginning to end.
	 */
	render(path: IRoutePath, markerLocations: Array<[
		number,
		number
	]>): void;
	/**
	 * @description Remove route from the map.
	 */
	remove(): void;
	/**
	 * @description Filter paths' opacity by venue and ordinal.
	 * @param venueId {string | null | undefined}
	 * @param ordinal {string | null | undefined}
	 */
	setFilterByVenue(venueId: string | null | undefined, ordinal: string | null | undefined): void;
	/**
	 * @description Filter paths' opacity by building and ordinal.
	 * @param buildingId {string | null | undefined}
	 * @param ordinal {string | null | undefined}
	 */
	setFilterByBuilding(buildingId: string | null | undefined, ordinal: string | null | undefined): void;
	private _classifyFeatures;
	private _createLineFeature;
	private _createIconFeature;
	private _renderSolidLines;
	private _renderDashedLines;
	private _renderConnectors;
	private _renderMarkers;
	private _addCollectionSource;
	private _addLineLayer;
	private _addTriangleLayer;
	private _addIconLayer;
}
export declare class VenuesService {
	private _api;
	private _request;
	constructor();
	/**
	 * @description Search venues by ids.
	 * @param ids Single id string or string ids in array. The number of IDs cannot exceed 10.
	 */
	searchByIds(ids: string | string[]): TPromiseVenues;
	/**
	 * @description Search venues by center and distance.
	 * @param keywords
	 * @param center
	 * @param distance Radius from center, unit is kilometers.
	 * @param offset The maximum value is 100, default is 10.
	 * @param page Default is 1.
	 */
	searchByDistance(keywords: string, center: [
		number,
		number
	], distance: number, offset?: number, page?: number): TPromiseVenues;
	/**
	 * @description Search venues in specified bbox.
	 * @param keywords
	 * @param bbox Rectangular area, [minLon, minLat, maxLon, maxLat].
	 * @param offset The maximum value is 100, default is 10.
	 * @param page Default is 1.
	 */
	searchByBbox(keywords: string, bbox: [
		number,
		number,
		number,
		number
	], offset?: number, page?: number): TPromiseVenues;
	/**
	 * @description Search venues by global.
	 * @param keywords
	 * @param offset The maximum value is 100, default is 10.
	 * @param page Default is 1.
	 */
	searchByGlobal(keywords: string, offset?: number, page?: number): TPromiseVenues;
	private _changedRes;
}
export declare class BuildingsService {
	private _api;
	private _request;
	constructor();
	/**
	 * @description Search buildings by id[s].
	 * @param ids Single id string or string ids in array. The number of IDs cannot exceed 10.
	 */
	searchByIds(ids: string | string[]): TPromiseBuildings;
	/**
	 * @description Search buildings by center and distance.
	 * @param keywords
	 * @param center
	 * @param distance Radius from center, unit is kilometers.
	 * @param offset The maximum value is 100, default is 10.
	 * @param page Default is 1.
	 */
	searchByDistance(keywords: string, center: number[], distance: number, offset?: number, page?: number): TPromiseBuildings;
	/**
	 * @description Search buildings in specified bbox.
	 * @param keywords
	 * @param bbox Rectangular area, [minLon, minLat, maxLon, maxLat].
	 * @param offset The maximum value is 100, default is 10.
	 * @param page Default is 1.
	 */
	searchByBbox(keywords: string, bbox: number[], offset?: number, page?: number): TPromiseBuildings;
	/**
	 * @description Search buildings global.
	 * @param keywords
	 * @param offset The maximum value is 100, default is 10.
	 * @param page Default is 1.
	 */
	searchByGlobal(keywords: string, offset?: number, page?: number): TPromiseBuildings;
	/**
	 * @description Search building by floor id.
	 * @param floorId
	 */
	searchByFloorId(floorId: string): TPromiseBuildings;
	private _changedRes;
}
export declare class PoisService {
	private _api;
	private _apiV4;
	private _categoriesV2;
	private _request;
	constructor();
	/**
	 * @description Search POIs by id[s].
	 * @param ids Single id string or string ids in array. The number of IDs cannot exceed 100.
	 */
	searchByIds(ids: string | string[]): TPromisePois;
	/**
	 * @description Search POIs by radius distance of the center point.
	 * @param options {IPoiSearchByDistanceOptions}
	 */
	searchByDistance(options: IPoiSearchByDistanceOptions): TPromisePois;
	/**
	 * @description Search POIs in a bbox.
	 * @deprecated Use searchByBounds instead.
	 * @param keywords
	 * @param bbox Rectangular area, [minLon, minLat, maxLon, maxLat].
	 * @param offset The maximum value is 100, default is 10.
	 * @param page Default is 1.
	 */
	searchByBbox(keywords: string, bbox: number[], offset?: number, page?: number): TPromisePois;
	/**
	 * @description Search POIs in a rectangular area.
	 * @param options {IPoiSearchByBoundsOptions}
	 * 'orderBy' cannot be used with 'keywords'.
	 */
	searchByBounds(options: IPoiSearchByBoundsOptions): TPromisePois;
	/**
	 * @description Search POIs of a building.
	 * @deprecated Use searchByBuilding instead.
	 * @param keywords
	 * @param buildingId
	 * @param offset The maximum value is 100, default is 10.
	 * @param page Default is 1.
	 */
	searchByBuildingId(keywords: string, buildingId: string, offset?: number, page?: number): TPromisePois;
	/**
	 * @description Search POIs of a building.
	 * @param options {IPoiSearchByBuildingOptions}
	 * 'orderBy' cannot be used with 'keywords'.
	 */
	searchByBuilding(options: IPoiSearchByBuildingOptions): TPromisePois;
	/**
	 * @description Search POIs of a venue.
	 * @deprecated Use searchByVenue instead.
	 * @param keywords
	 * @param venueId
	 * @param offset
	 * @param page
	 */
	searchByVenueId(keywords: string, venueId: string, offset?: number, page?: number): TPromisePois;
	/**
	 * @description Search POIs of a venue.
	 * @param options {IPoiSearchByVenueOptions}
	 * 'orderBy' cannot be used with 'keywords'.
	 */
	searchByVenue(options: IPoiSearchByVenueOptions): TPromisePois;
	/**
	 * @description Search POIs of a floor.
	 * @param options {IPoiSearchByFloorOptions}
	 * 'orderBy' cannot be used with 'keywords'.
	 */
	searchByFloor(options: IPoiSearchByFloorOptions): TPromisePois;
	/**
	 * @description Search poi categories by venue id, building id, or floor id.
	 * Search scope priority: floorId > buildingId > venueId.
	 * @param paramObject
	 */
	searchCategories(paramObject: {
		venueId?: string;
		buildingId?: string;
		floorId?: string;
	}): TPromiseCategories;
	/**
	 * @description Search surrounding POIs based on the user's location and orientation.
	 * BuildingId, floorId and ordinal are mutually exclusive, priority: ordinal > floorId > buildingId.
	 * @deprecated Use searchByOrientation instead.
	 * @param options
	 */
	searchOrientation(options: IPoiSearchOrientationOptions): TPromiseOrientationPois;
	/**
	 * @description Search surrounding POIs based on the user's location and orientation.
	 * @param options {TPoiSearchByOrientationOptions}
	 */
	searchByOrientation(options: TPoiSearchByOrientationOptions): TPromiseOrientationPois;
	/**
	 * @description Search POIs by category or excluded categories.
	 * @param options {TPoiSearchByCategoryOptions}
	 */
	searchByCategory(options: TPoiSearchByCategoryOptions): TPromisePois;
	private _changedRes;
}
export declare class RouteService {
	private _api;
	private _request;
	constructor();
	/**
	 * @description Search the route of two or more points.
	 * @param options {IRouteSearchOptions}
	 */
	search(options: IRouteSearchOptions): TPromiseRoute;
}
export declare const OFFSET: number;
export declare const PAGE: number;
/**
 * @description Convert browser language to preset language
 * @param language {string} window.navigator.language
 */
export declare function convertBrowserLangToPresetLang(language: string): PresetLanguage | null;
/** @deprecated Use `VERSION` instead. */
export declare const version: string;
export declare const VERSION: string;

export {
	Map$1 as Map,
};

export {};
